%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Define hrss@50% results for each waveform and each pipeline for O3a.
% Source : https://git.ligo.org/publications/O3/o3-burst-long-transient/-/issues/16
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

PIPELINES = {'Zebragard','Lonetrack','cWB','X'};

dic = classes.waveforms.dictionary;

%% === ZEBRAGARD === %% 
% source https://git.ligo.org/publications/O3/o3-burst-long-transient/-/blob/master/script/eff/stamp_zebragard_O3a.csv
% GRB plateau
T.Zebragard.GRBplateauShort = 5.6379e-22;
% ISCO chirp
T.Zebragard.ISCOchirpA = 2.8006e-21;
T.Zebragard.ISCOchirpB = 8.4635e-22;
T.Zebragard.ISCOchirpC = 4.8937e-22;
% NCSA-CAM 
T.Zebragard.NCSACAM_A = 9.0537e-22;
T.Zebragard.NCSACAM_B = 7.8528e-22;
T.Zebragard.NCSACAM_C = 6.1333e-22;
T.Zebragard.NCSACAM_D = 9.8679e-22;
T.Zebragard.NCSACAM_E = 8.9468e-22;
T.Zebragard.NCSACAM_F = 6.2986e-22;
T.Zebragard.NCSACAM_G = 1.389e-21;
T.Zebragard.NCSACAM_H = 1.8901e-21;
T.Zebragard.NCSACAM_I = 1.1803e-21;
% ADI 
T.Zebragard.adiB = 2.9079e-22;
% MAGNETAR 
T.Zebragard.maXgnetarD = 3.4574e-21;
T.Zebragard.maXgnetarE = 2.0943e-21;
T.Zebragard.maXgnetarF = 1.0861e-21;

% SG
T.Zebragard.sgC = 2.5811e-21;
% WNB 
T.Zebragard.wnbA = 1.0471e-21;
T.Zebragard.wnbB = 1.1297e-21;

%% === LONETRACK === %%
% source https://git.ligo.org/publications/O3/o3-burst-long-transient/-/blob/master/script/eff/stamp_lonetrack_O3a.csv
% GRB plateau
T.Lonetrack.GRBplateauShort = 5.114e-22;
% ISCO CHIRP
T.Lonetrack.ISCOchirpA = 3.3108e-21;
T.Lonetrack.ISCOchirpB = 1.2177e-21;
T.Lonetrack.ISCOchirpC = 6.9405e-22;
% NCSA-CAM
T.Lonetrack.NCSACAM_A = 1.0754e-21;
T.Lonetrack.NCSACAM_B = 1.392e-21;
T.Lonetrack.NCSACAM_C = 1.4265e-21;
T.Lonetrack.NCSACAM_D = 1.4254e-21;
T.Lonetrack.NCSACAM_E = 1.7407e-21;
T.Lonetrack.NCSACAM_F = 3.4145e-21;
T.Lonetrack.NCSACAM_G = 2.4504e-21;
T.Lonetrack.NCSACAM_H = 2.1944e-21;
T.Lonetrack.NCSACAM_I = 3.0205e-21;
% ADI
T.Lonetrack.adiB = 4.5611e-22;
% Magnetar
T.Lonetrack.maXgnetarD = 1.6174e-21;
T.Lonetrack.maXgnetarE = 1.1256e-21;
T.Lonetrack.maXgnetarF = 7.8583e-22;
% SG 
T.Lonetrack.sgC = 1.286e-20;
% WNB 
T.Lonetrack.wnbA = 2.0591e-20;
T.Lonetrack.wnbB = 2.6608e-20;

%% === C WB === %%
% source https://wiki.ligo.org/Bursts/CWB_BurstLD_O3a
% GRB plateau
T.cWB.GRBplateauShort = NaN;
% ISCO CHIRP
T.cWB.ISCOchirpA = 1.43e-21 ;
T.cWB.ISCOchirpB = 8.74e-22 ;
T.cWB.ISCOchirpC =  5.78e-22 ;
% NCSA-CAM
T.cWB.NCSACAM_A = 8.38e-22 ;
T.cWB.NCSACAM_B = 8.27e-22 ;
T.cWB.NCSACAM_C = 8.95e-22 ;
T.cWB.NCSACAM_D = 1.48e-21 ;
T.cWB.NCSACAM_E = 1.53e-21 ;
T.cWB.NCSACAM_F = 1.37e-21 ;
T.cWB.NCSACAM_G = 5.72e-21 ;
T.cWB.NCSACAM_H = 4.06e-21 ;
T.cWB.NCSACAM_I = 2.17e-21 ;
% ADI
T.cWB.adiB = 2.80e-22 ;
% MAGNETAR
T.cWB.maXgnetarD = 2.97e-21 ;
T.cWB.maXgnetarE = 2.05e-21 ;
T.cWB.maXgnetarF = 1.34e-21 ;
% SG
T.cWB.sgC = NaN;
% WNB 
T.cWB.wnbA =  1.42e-21 ;
T.cWB.wnbB =  1.52e-21 ;

%% === X === %%
% source https://git.ligo.org/publications/O3/o3-burst-long-transient/-/blob/master/script/eff/XSphRad_O3a.csv
% GRB plateau
T.X.GRBplateauShort = 9.24074e-21;
% ISCO CHIRP
T.X.ISCOchirpA = 3.49064e-21;
T.X.ISCOchirpB = 5.21239e-21;
T.X.ISCOchirpC = 3.02087e-21;
% NCSA-CAM
T.X.NCSACAM_A = 2.04357e-20;
T.X.NCSACAM_B = 9.20058e-21;
T.X.NCSACAM_C = 5.50949e-21;
T.X.NCSACAM_D = 1.87546e-20;
T.X.NCSACAM_E = 1.26574e-20;
T.X.NCSACAM_F = 3.16893e-21;
T.X.NCSACAM_G = NaN;
T.X.NCSACAM_H = NaN;
T.X.NCSACAM_I = NaN;
% ADI
T.X.adiB = 2.10876e-21;
% MAGNETAR
T.X.maXgnetarD = 1.9014e-20;
T.X.maXgnetarE = 6.06698e-21;
T.X.maXgnetarF = 6.74041e-21;
% SG 
T.X.sgC = NaN;
% WNB 
T.X.wnbA = NaN;
T.X.wnbB = NaN;
