%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LES_paper_plot :
% PURPOSE :
%
%
% AUTHOR  : Valentin FREY
% CONTACT : frey@lal.in2p3.fr
% VERSION : 1.0
% DATE    : 




COLOR=parula(11);
%COLOR=autumn(length(WVFS));
addpath(genpath('../'))
import classes.waveforms.dictionary
dic = dictionary;


% O3 plot

WVFS = {'NCSACAM_A','NCSACAM_B','NCSACAM_C','NCSACAM_D','NCSACAM_E','NCSACAM_F', 'NCSACAM_G', 'NCSACAM_H', 'NCSACAM_I'};
LES_PIPELINES={'Zebragard_O3a', 'Zebragard_O3b', 'Lonetrack_O3a', 'Lonetrack_O3b', 'cWB', 'X_O3a', 'X_O3b'};
COLOR = autumn(length(WVFS));

RESULTS_O3a % Ta
RESULTS_O3b % Tb
RESULTS_O2 % T
%params
XMIN = 1;
XMAX = 500;
DATA_DIR = fileparts(mfilename('fullpath'));

figure('Position',[0 0 800 600])
hold all
ax=gca;
set(ax,'XScale','Log')
set(ax,'YScale','Log')
xlim([XMIN XMAX]);

Tobs_O3 = 204.7 * 86400;
Npoints=1000;
YY=zeros(Npoints,length(WVFS));
for w_idx=1:length(WVFS)
    w = WVFS{w_idx};

    % Find best pipeline and best between O3a and O3b
    p_O3a = bestPip(Ta,w);
    p_O3b = bestPip(Tb,w);
    Tobs = Tobs_O3;
    %display([WVFS{w_idx} ' ' p ' ' num2str(Tobs)])


    if Ta.(p_O3a).(w) < Tb.(p_O3b).(w)
      p = p_O3a;
      sub = '_O3a';
    else
      p = p_O3b;
      sub = '_O3b'
    end
    % Only zebragrd
    %p = 'Zebragard'
	%sub = '_O3a'
    data=load([DATA_DIR '/' p sub '/' w '.dat']);
    dist = dic.headers(w).distance./data(:,1).* ...
           dic.headers(w).hrss;
    XMIN = min(XMIN,min(dist));
    XMAX = max(XMAX,max(dist));

    cfit = fit_eff(dist,data(:,4));
    coeff = 2.3/(Tobs/(86400*365.25));

    X = logspace(log10(XMIN),log10(XMAX),Npoints)';
    Y = coeff./cfit(X);

    YY(:,w_idx)=Y;

    plot(X,Y,'-',...
         'LineWidth',2,...
         'Color',COLOR(w_idx,:));
end



box
grid minor
l=legend(regexprep(WVFS,'(.*)\_','ECBC\\_'),'Location','NorthEast');
l.FontSize = 13;
l.Position = [0.6 0.650 0.1125 0.1571];

ax.FontSize = 20
xlabel('Distance [Mpc]',...
       'Interpreter','latex',...
       'FontSize',28);
ylabel('Rate Upper limit [\#/yr]',...
       'Interpreter','latex',...
       'FontSize',28);

% O2 results

WVFS_O2 = {'NCSACAM_A','NCSACAM_B','NCSACAM_C','NCSACAM_D','NCSACAM_E','NCSACAM_F'};
LES_PIPELINES_O2={'Zebragard', 'Lonetrack', 'cWB', 'X'};

% == AXIS 2 == %%
% ================================================================== %%
ax2 = axes('Position',[.220 .369 .35 .53]);
hold all


DATA_DIR_O2 = strcat(DATA_DIR, '/O2_results');
Npoints=1000;
YY=zeros(Npoints,length(WVFS_O2));
for w_idx=1:length(WVFS_O2)
    w = WVFS_O2{w_idx};

    % Find best pipeline
    p = bestPip(T,w);

    %p = 'Zebragard'

    Tobs = T.(p).T_OBS_ZL
    %display([WVFS{w_idx} ' ' p ' ' num2str(Tobs)])


    data=load([DATA_DIR_O2 '/' p '/' w '.dat']);
    dist = dic.headers(w).distance./data(:,1).* ...
           dic.headers(w).hrss;
    XMIN = min(XMIN,min(dist));
    XMAX = max(XMAX,max(dist));
    XMIN = 1;
    XMAX = 500;
    X = logspace(log10(XMIN),log10(XMAX),Npoints)';

    % O3 result

    p_O3a = bestPip(Ta,w);
    p_O3b = bestPip(Tb,w);

    if Ta.(p_O3a).(w) < Tb.(p_O3b).(w)
      p = p_O3a;
      sub = '_O3a';
    else
      p = p_O3b;
      sub = '_O3b'
    end

    % Zebragard only
       %p =  'Zebragard'
       %sub = '_O3a';

    data_O3=load([DATA_DIR '/' p sub '/' w '.dat']);
dist_O3 = dic.headers(w).distance./data_O3(:,1).*dic.headers(w).hrss;
    cfit_O3 = fit_eff(dist_O3,data_O3(:,4));
    coeff_O3 = 2.3/(Tobs_O3/(86400*365.25));


    cfit = fit_eff(dist,data(:,4));
    coeff = 2.3/(Tobs/(86400*365.25));


    Y = coeff./cfit(X);
Y_O3 = coeff_O3 ./cfit_O3(X);
    YY(:,w_idx)=Y;

    plot(X,Y./Y_O3,'--',...
         'LineWidth',1,...
         'HandleVisibility', 'off',...
         'Color',COLOR(w_idx,:));
end
box

xlabel('Distance [Mpc]','Interpreter','latex','FontSize',12)
ylabel('O2 vs O3 ratio', 'Fontsize', 12)
ax2.YMinorGrid='on';
set(ax2, 'XScale', 'Log')
set(ax2, 'YScale', 'Log')
ax2.FontSize = 17;
%save('LES_b_4.mat')
h = gcf;
set(h, 'PaperOrientation', 'landscape')
print('-dpdf',['../plots/ECBC_rate.pdf']);

